import { ValidationError } from 'class-validator';
import { eRfidApplicationType } from '../../../../consts';
import { iRRfidDataGroupStatusItem, RRfidDataGroupStatusItem } from './rfid-data-group-status-item.model';
import { AllowPrimitives } from '../../../../types';
/**
 * Rfid application item
 */
export interface iRRfidApplicationItem {
    /**
     * Application type
     * @type {eRfidApplicationType}
     */
    type: eRfidApplicationType;
    /**
     * Groups
     * @type {iRRfidDataGroupStatusItem[]}
     */
    groups: iRRfidDataGroupStatusItem[];
}
/**
 * Rfid application item
 */
export declare class RRfidApplicationItem implements iRRfidApplicationItem {
    /**
     * Application type
     * @type {eRfidApplicationType}
     */
    type: eRfidApplicationType;
    /**
     * Groups
     * @type {RRfidDataGroupStatusItem[]}
     */
    groups: RRfidDataGroupStatusItem[];
    /**
     * Create instance of RRfidApplicationItem from plain object
     * @param {AllowPrimitives<iRRfidApplicationItem>} input - plain object
     * @returns {RRfidApplicationItem}
     */
    static fromPlain: (input: AllowPrimitives<iRRfidApplicationItem>) => RRfidApplicationItem;
    /**
     * Gets validation errors of RRfidApplicationItem
     * @param {RRfidApplicationItem} input - input data
     * @returns {ValidationError[]} - array of validation errors
     */
    static getValidationErrors: (input: RRfidApplicationItem) => ValidationError[];
}
